@@ -354,14 +354,22 @@ void mp::NameProvider::ReadNames(
 }
 
 fmt::StringRef mp::NameProvider::name(
-    std::size_t index, std::size_t i2) {
+		std::size_t index, std::size_t i2, bool* was_empty) {
   if (index + 1 < names_.size()) {
     const char *name = names_[index];
     const auto* pos1past = names_[index + 1] - 1;
     assert( ('\n' == *pos1past) || ('\r' == *pos1past));
     if (pos1past>name && '\r' == *(pos1past-1))            // Windows
       --pos1past;
-    return fmt::StringRef(name, pos1past - name);
+		while (isspace(*name) && name < pos1past)              // trim left
+			++name;
+		while (name < pos1past && isspace(*(pos1past-1)))      // trim right
+			--pos1past;
+		if (name < pos1past)
+			return fmt::StringRef(name, pos1past - name);
+		else
+			if (was_empty)
+				*was_empty = true;
   }
   writer_.clear();
   if (index>=i2)
@@ -376,11 +384,11 @@ size_t mp::NameProvider::number_read() const {
 }
 
 std::vector<std::string> mp::NameProvider::get_names(
-    size_t n, size_t i2) {
+		size_t n, size_t i2, bool* any_empty) {
   std::vector<std::string> result;
   result.reserve(n);
   for (size_t i=0; i<n; ++i)
-    result.push_back(name(i, i2));
+		result.push_back(name(i, i2, any_empty));
   return result;
 }
 
