@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -81,7 +81,7 @@ struct SCIP_ConshdlrData
  * above the feasibility tolerance by aggregation factors. Usually, the violation should still be
  * rather "small". For this test, we quantify "small" as 0.5.
  */
-#define assertSmallViolation(lb, val, ub) (assert((val) >= (lb) - 0.5 && (val) <= (ub) + 0.5));
+#define assertSmallViolation(lb, val, ub) (assert((val) >= (lb) - 0.5 && (val) <= (ub) + 0.5))
 
 /** add cut to enforce global bounds on variable aggregation
  *
@@ -162,7 +162,6 @@ SCIP_DECL_CONSHDLRCOPY(conshdlrCopyFixedvar)
 static
 SCIP_DECL_CONSFREE(consFreeFixedvar)
 {  /*lint --e{715}*/
-
    SCIP_CONSHDLRDATA* conshdlrdata;
 
    conshdlrdata = SCIPconshdlrGetData(conshdlr);
@@ -513,7 +512,7 @@ SCIP_DECL_CONSCHECK(consCheckFixedvar)
 
          if( printreason )
          {
-            SCIPinfoMessage(scip, NULL, "solution violates lower bound of fixed variable <%s> [%g,%g], solution value <%g>\n",
+            SCIPinfoMessage(scip, NULL, "solution violates lower bound of non-active variable <%s> [%g,%g], solution value <%g>\n",
                SCIPvarGetName(vars[i]), lb, ub, val);
          }
 
@@ -533,7 +532,7 @@ SCIP_DECL_CONSCHECK(consCheckFixedvar)
 
          if( printreason )
          {
-            SCIPinfoMessage(scip, NULL, "solution violates upper bound of fixed variable <%s> [%g,%g], solution value <%g>\n",
+            SCIPinfoMessage(scip, NULL, "solution violates upper bound of non-active variable <%s> [%g,%g], solution value <%g>\n",
                SCIPvarGetName(vars[i]), lb, ub, val);
          }
 
